==> haskell-network-2.6.3.2-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-network.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network
version: 2.6.3.2
id: network-2.6.3.2-IsLM4TXcLoRI0fmmBYVyQz
key: network-2.6.3.2-IsLM4TXcLoRI0fmmBYVyQz
license: BSD3
maintainer: Kazu Yamamoto, Evan Borden
homepage: https://github.com/haskell/network
synopsis: Low-level networking interface
description:
    This package provides a low-level networking interface.
    .
    In network-2.6 the @Network.URI@ module was split off into its own
    package, network-uri-2.6. If you'\''re using the @Network.URI@ module
    you can automatically get it from the right package by adding this
    to your .cabal file:
    .
    > flag network-uri
    >   description: Get Network.URI from the network-uri package
    >   default: True
    >
    > library
    >   -- ...
    >   if flag(network-uri)
    >     build-depends: network-uri >= 2.6, network >= 2.6
    >   else
    >     build-depends: network-uri < 2.6, network < 2.6
    .
    That is, get the module from either network < 2.6 or from
    network-uri >= 2.6.
category: Network
exposed: True
exposed-modules:
    Network Network.BSD Network.Socket Network.Socket.ByteString
    Network.Socket.ByteString.Lazy Network.Socket.Internal
hidden-modules: Network.Socket.ByteString.Internal
                Network.Socket.Types Network.Socket.ByteString.IOVec
                Network.Socket.ByteString.Lazy.Posix
                Network.Socket.ByteString.MsgHdr
abi: 67243d3d4dc8f9bb00eba3f7aa6117d9
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/network-2.6.3.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/network-2.6.3.2
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/network-2.6.3.2
hs-libraries: HSnetwork-2.6.3.2-IsLM4TXcLoRI0fmmBYVyQz
include-dirs: /usr/lib/ghc-8.0.2/site-local/network-2.6.3.2/include
includes:
    HsNet.h
depends:
    base-4.9.1.0 bytestring-0.10.8.1 unix-2.7.2.1
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro"
haddock-interfaces: /usr/share/doc/haskell-network/html/network.haddock
haddock-html: /usr/share/doc/haskell-network/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-2.6.3.2-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-network.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network
version: 2.6.3.2
id: network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
key: network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
license: BSD3
maintainer: Kazu Yamamoto, Evan Borden
homepage: https://github.com/haskell/network
synopsis: Low-level networking interface
description:
    This package provides a low-level networking interface.
    .
    In network-2.6 the @Network.URI@ module was split off into its own
    package, network-uri-2.6. If you'\''re using the @Network.URI@ module
    you can automatically get it from the right package by adding this
    to your .cabal file:
    .
    > flag network-uri
    >   description: Get Network.URI from the network-uri package
    >   default: True
    >
    > library
    >   -- ...
    >   if flag(network-uri)
    >     build-depends: network-uri >= 2.6, network >= 2.6
    >   else
    >     build-depends: network-uri < 2.6, network < 2.6
    .
    That is, get the module from either network < 2.6 or from
    network-uri >= 2.6.
category: Network
exposed: True
indefinite: False
exposed-modules:
    Network Network.BSD Network.Socket Network.Socket.ByteString
    Network.Socket.ByteString.Lazy Network.Socket.Internal
hidden-modules: Network.Socket.ByteString.Internal
                Network.Socket.Types Network.Socket.ByteString.IOVec
                Network.Socket.ByteString.Lazy.Posix
                Network.Socket.ByteString.MsgHdr
abi: dc3f2353580d7555dd3bad96e9f5af9d
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/network-2.6.3.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/network-2.6.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/network-2.6.3.2
hs-libraries: HSnetwork-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
include-dirs: /usr/lib/ghc-8.2.1/site-local/network-2.6.3.2/include
includes:
    HsNet.h
depends:
    base-4.10.0.0 bytestring-0.10.8.2 unix-2.7.2.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             unix-2.7.2.2=53184c24da5ad45126d145b2febba63d
ld-options: "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now"
haddock-interfaces: /usr/share/doc/haskell-network/html/network.haddock
haddock-html: /usr/share/doc/haskell-network/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
